# docker-minix2

Permite la ejecución de Minix 2 sobre QEMU en contenedores Docker. Necesario tener instalado `docker` y `docker-compose`.

Crea dos contenedores:
* Uno basado en [QEMU/i386](https://hub.docker.com/r/qemu/i386) con el puerto 5901 abierto para acceder a Minix mediante un visor VNC
* Otro basado en [Debian 10](https://hub.docker.com/_/debian) desde el que se puede montar el sistema de archivos Minix y sincronizar con git

## Configuración
Variables de entorno:
* debian: 
    * `GIT_REPO`: repositorio de git. Sin valor por defecto
    * `GIT_USER`: usuario de git. Sin valor por defecto
    * `GIT_EMAIL`: e-mail de git. Sin valor por defecto
* qemu:
    * `RAM_SIZE`: tamaño de la memoria RAM para Minix en MB. Por defecto 16

## Despliegue

`docker-compose up --build -d`

## Scripts
Existen los siguientes scripts en la carpeta `/home/scripts` de Debian a los que se puede acceder a través de `bash`:
* `runme.sh`: monta, sincroniza, hace push y desmonta el sistema de archivos Minix
* `mount.sh`: monta Minix en `/mnt` y `/mnt/usr`
* `rsync.sh`: sincroniza el sistema de archivos de Minix en `/home/git`
* `git.sh`: añade todos los archivos de `/home/git`, realiza el commit y el push en el repositorio remoto que se especificó
* `umount.sh`: desmonta `/mnt` y `/mnt/usr`. Es posible que falle a veces si se han hecho escrituras en dicho directorio, si es así, ejecutar hasta que se desmonte

## Uso
Minix se puede acceder a través de un visor VNC desde `127.0.0.1:5901`

### Sincronizar con git
1. Parar el contenedor de QEMU con `docker stop <contenedor>`
2. Ejecutar `bash` en el contenedor con Debian (`docker exec -it <contenedor> bash`)
3. Dentro de la terminal de Debian, ejecutar `sh /home/scripts/runme.sh`
4. Introducir los datos de inicio de sesión

### Añadir archivos a Minix
Es posible añadir archivos locales en Minix a través de Debian, pero solo en el punto de montaje `/mnt/usr`:
1. Parar el contenedor de QEMU con `docker stop <contenedor>`
2. Ejecutar `bash` en el contenedor con Debian (`docker exec -it <contenedor> bash`)
3. Dentro de la terminal de Debian, ejecutar `sh /home/scripts/mount.sh`
4. Añadir los archivos que queramos en `/mnt/usr`. El tamaño de la partición es de unos 44MB.
5. Desmontar con `sh /home/scripts/umount.sh`